==> zio-aws-route53resolver_2.13-5.17.104.3-sources.jar: zio/aws/route53resolver/model/AssociateResolverRuleResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AssociateResolverRuleResponse(
    resolverRuleAssociation: Option[
      zio.aws.route53resolver.model.ResolverRuleAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse = {
    import AssociateResolverRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
      .builder()
      .optionallyWith(
        resolverRuleAssociation.map(value => value.buildAwsValue())
      )(_.resolverRuleAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.AssociateResolverRuleResponse.ReadOnly =
    zio.aws.route53resolver.model.AssociateResolverRuleResponse
      .wrap(buildAwsValue())
}
object AssociateResolverRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.AssociateResolverRuleResponse =
      zio.aws.route53resolver.model.AssociateResolverRuleResponse(
        resolverRuleAssociation.map(value => value.asEditable)
      )
    def resolverRuleAssociation
        : Option[zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly]
    def getResolverRuleAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverRuleAssociation",
      resolverRuleAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
  ) extends zio.aws.route53resolver.model.AssociateResolverRuleResponse.ReadOnly {
    override val resolverRuleAssociation: Option[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = scala
      .Option(impl.resolverRuleAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverRuleAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
  ): zio.aws.route53resolver.model.AssociateResolverRuleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_2.13-6.20.42.1-sources.jar: zio/aws/route53resolver/model/AssociateResolverRuleResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AssociateResolverRuleResponse(
    resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse = {
    import AssociateResolverRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
      .builder()
      .optionallyWith(
        resolverRuleAssociation.map(value => value.buildAwsValue())
      )(_.resolverRuleAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.AssociateResolverRuleResponse.ReadOnly =
    zio.aws.route53resolver.model.AssociateResolverRuleResponse
      .wrap(buildAwsValue())
}
object AssociateResolverRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.AssociateResolverRuleResponse =
      zio.aws.route53resolver.model.AssociateResolverRuleResponse(
        resolverRuleAssociation.map(value => value.asEditable)
      )
    def resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ]
    def getResolverRuleAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverRuleAssociation",
      resolverRuleAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
  ) extends zio.aws.route53resolver.model.AssociateResolverRuleResponse.ReadOnly {
    override val resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.resolverRuleAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverRuleAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverRuleResponse
  ): zio.aws.route53resolver.model.AssociateResolverRuleResponse.ReadOnly =
    new Wrapper(impl)
}
